@@ -6,8 +6,8 @@ const MIN_MAX_CODE: &str = "local x = { 1, 2, 3 }";
 fn test_position_min_max() {
     struct TestVisitor(bool);
 
-    impl<'ast> Visitor<'ast> for TestVisitor {
-        fn visit_table_constructor(&mut self, constructor: &ast::TableConstructor<'ast>) {
+    impl Visitor for TestVisitor {
+        fn visit_table_constructor(&mut self, constructor: &ast::TableConstructor) {
             self.0 = true;
             assert_eq!(
                 MIN_MAX_CODE
